Learn R Programming

gMCPLite (version 0.1.7)

bdiagNA: Create a Block Diagonal Matrix with NA outside the diagonal

Description

Build a block diagonal matrix with NA values outside the diagonal given several building block matrices.

Usage

bdiagNA(...)

Value

A block diagonal matrix with NA values outside the diagonal.

Arguments

...

individual matrices or a list of matrices.

Author

Kornelius Rohmeyer rohmeyer@small-projects.de

Details

This function is useful to build the correlation matrices, when only partial knowledge of the correlation exists.

See Also

gMCP

Examples

Run this code
bdiagNA(diag(3), matrix(1/2,nr=3,nc=3), diag(2))

Run the code above in your browser using DataLab