Learn R Programming

gMCPLite (version 0.1.6)

gMCPResult-class: Class gMCPResult

Description

A gMCPResult object describes an evaluated sequentially rejective multiple test procedure.

Arguments

Slots

graphs

Object of class list.

alpha

A numeric specifying the maximal type I error rate.

pvalues

The numeric vector of p-values.

rejected

The logical vector of rejected null hypotheses.

adjPValues

The numeric vector of adjusted p-values.

Author

Kornelius Rohmeyer rohmeyer@small-projects.de

See Also

gMCP