Learn R Programming

gMCPLite (version 0.1.6)

gMCPLite-package: gMCPLite: Lightweight Graph Based Multiple Comparison Procedures

Description

logo

A lightweight fork of 'gMCP' with functions for graphical described multiple test procedures introduced in Bretz et al. (2009) tools:::Rd_expr_doi("10.1002/sim.3495") and Bretz et al. (2011) tools:::Rd_expr_doi("10.1002/bimj.201000239"). Implements a flexible function using 'ggplot2' to create multiplicity graph visualizations. Contains instructions of multiplicity graph and graphical testing for group sequential design, described in Maurer and Bretz (2013) tools:::Rd_expr_doi("10.1080/19466315.2013.807748"), with necessary unit testing using 'testthat'.

Arguments

Author

Maintainer: Nan Xiao nan.xiao1@merck.com (ORCID)

Authors:

Other contributors:

  • Kornelius Rohmeyer rohmeyer@small-projects.de (gMCP author) [contributor]

  • Florian Klinglmueller float@lefant.net (gMCP author) [contributor]

  • gMCP project contributors (gMCP package) [copyright holder]

  • Merck & Co., Inc., Rahway, NJ, USA and its affiliates [copyright holder]

See Also